@@ -10,6 +10,11 @@ class InvalidStateTransition(Exception):
 class AbortStateTransition(Exception):
     pass
 
+def wrap_with_tuple(what):
+    if isinstance(what, (tuple, list)):
+        return tuple(what)
+    return (what,)
+
 class State(object):
     def __init__(self, initial=False, **kwargs):
         self.initial = initial
@@ -30,17 +35,6 @@ class State(object):
 class Event(object):
     def __init__(self, **kwargs):
         self.to_state = kwargs.get('to_state', None)
-        self.from_states = tuple()
-        from_state_args = kwargs.get('from_states', tuple())
-        if isinstance(from_state_args, (tuple, list)):
-            self.from_states = tuple(from_state_args)
-        else:
-            self.from_states = (from_state_args,)
-        self.parameters = tuple()
-        parameters_args = kwargs.get('parameters', tuple())
-        if isinstance(parameters_args, (tuple, list)):
-            self.parameters = tuple(parameters_args)
-        else:
-            self.parameters = (parameters_args,)
-
+        self.from_states = wrap_with_tuple(kwargs.get('from_states', tuple()))
+        self.parameters = wrap_with_tuple(kwargs.get('parameters', tuple()))
         
\ No newline at end of file
